[prev in list] [next in list] [prev in thread] [next in thread] 

List:       lon-capa-cvs
Subject:    [LON-CAPA-cvs] cvs: loncom / lond /homework grades.pm inputtags.pm /html/adm/help/tex BridgeTask_Edi
From:       bisitz <bisitz () source ! lon-capa ! org>
Date:       2013-04-11 14:59:59
Message-ID: cvsbisitz1365692399 () cvsserver
[Download RAW message or body]

This is a MIME encoded message


bisitz		Thu Apr 11 14:59:59 2013 EDT

  Modified files:              
    /loncom	lond 
    /loncom/homework	grades.pm inputtags.pm 
    /loncom/html/adm/help/tex	BridgeTask_EditMode.tex 
                             	BridgeTask_EditModeFinishing.tex 
                             	BridgeTask_XMLFinishing.tex 
                             	Portfolio_About.tex 
                             	Portfolio_OpenFile.tex 
                             	Portfolio_RenameFile.tex 
                             	Portfolio_ShareFile.tex 
    /loncom/interface	domainprefs.pm loncommon.pm portfolio.pm 
    /loncom/localize/localize	de.pm pt.pm zh.pm 
    /loncom/publisher	loncfile.pm testbankimport.pm 
  Log:
  Consistent wording: "file name" vs. "filename"
  Use "filename" since this is more commonly used.
  
  
["bisitz-20130411145959.txt" (text/plain)]

Index: loncom/lond
diff -u loncom/lond:1.499 loncom/lond:1.500
--- loncom/lond:1.499	Thu Apr  4 14:56:36 2013
+++ loncom/lond	Thu Apr 11 14:59:29 2013
@@ -2,7 +2,7 @@
 # The LearningOnline Network
 # lond "LON Daemon" Server (port "LOND" 5663)
 #
-# $Id: lond,v 1.499 2013/04/04 14:56:36 raeburn Exp $
+# $Id: lond,v 1.500 2013/04/11 14:59:29 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -61,7 +61,7 @@
 my $status='';
 my $lastlog='';
 
-my $VERSION='$Revision: 1.499 $'; #' stupid emacs
+my $VERSION='$Revision: 1.500 $'; #' stupid emacs
 my $remoteVERSION;
 my $currenthostid="default";
 my $currentdomainid;
@@ -154,8 +154,8 @@
 my @installerrors = ("ok",
 		     "Initial user id of client not that of www",
 		     "Usage error, not enough command line arguments",
-		     "Source file name does not exist",
-		     "Destination file name does not exist",
+		     "Source filename does not exist",
+		     "Destination filename does not exist",
 		     "Some file operation failed",
 		     "Invalid table filename."
 		     );
Index: loncom/homework/grades.pm
diff -u loncom/homework/grades.pm:1.685 loncom/homework/grades.pm:1.686
--- loncom/homework/grades.pm:1.685	Thu Apr 11 14:08:02 2013
+++ loncom/homework/grades.pm	Thu Apr 11 14:59:39 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Grading handler
 #
-# $Id: grades.pm,v 1.685 2013/04/11 14:08:02 bisitz Exp $
+# $Id: grades.pm,v 1.686 2013/04/11 14:59:39 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -3101,7 +3101,7 @@
                         &Apache::lonnet::dirlist($portfolio_root.$portfolio_path,
                                                  $domain,$stuname,$getpropath);
 		    my $version = &get_next_version($answer_name,$answer_ext,$dir_list);
-                    # fix file name
+                    # fix filename
                     my ($save_file_name) = \
                (($directory.$answer_name.".$version.".$answer_ext) =~ \
                /^.+\/${stuname}\/(.*)/);
                     my \
                $result=&Apache::lonnet::finishuserfileupload($stuname,$domain,
             	                                \
$newflg.'_'.$part_resp.'_returndoc'.$counter, @@ -3120,7 +3120,7 @@
                         $$newrecord{"resource.$new_part.$resp_id.handback"} .= \
$save_file_name;  $file_msg.= '<span class="LC_filename"><a \
href="/uploaded/'."$domain/$stuname/".$save_file_name.'">'.$save_file_name."</a></span> \
<br />";  }
-                    $request->print('<br />'.&mt('[_1] will be the uploaded file \
name [_2]','<span class="LC_info">'.$fname.'</span>','<span \
class="LC_filename">'.$env{'form.'.$newflg.'_'.$part_resp.'_origdoc'.$counter}.'</span>'));
 +                    $request->print('<br />'.&mt('[_1] will be the uploaded \
filename [_2]','<span class="LC_info">'.$fname.'</span>','<span \
class="LC_filename">'.$env{'form.'.$newflg.'_'.$part_resp.'_origdoc'.$counter}.'</span>'));
  }
             }
         }
@@ -8489,7 +8489,7 @@
     if (! &valid_file($file)) {
 	$r->print('
 	<p>
-	    '.&mt('The requested file name was invalid.').'
+	    '.&mt('The requested filename was invalid.').'
         </p>
 ');
 	return;
Index: loncom/homework/inputtags.pm
diff -u loncom/homework/inputtags.pm:1.314 loncom/homework/inputtags.pm:1.315
--- loncom/homework/inputtags.pm:1.314	Fri Dec 28 18:22:13 2012
+++ loncom/homework/inputtags.pm	Thu Apr 11 14:59:40 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.314 2012/12/28 18:22:13 raeburn Exp $
+# $Id: inputtags.pm,v 1.315 2013/04/11 14:59:40 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1078,7 +1078,7 @@
         } else {
             $message .= '<br />';
         }
-        $message .= &mt('Please use a different file name.');
+        $message .= &mt('Please use a different filename.');
         $css_class=$possible_class{'not_charged_try'};
         $button=1;
     } elsif ($award eq 'INVALID_FILETYPE') {
Index: loncom/html/adm/help/tex/BridgeTask_EditMode.tex
diff -u loncom/html/adm/help/tex/BridgeTask_EditMode.tex:1.1 \
                loncom/html/adm/help/tex/BridgeTask_EditMode.tex:1.2
--- loncom/html/adm/help/tex/BridgeTask_EditMode.tex:1.1	Wed May 30 15:35:14 2007
+++ loncom/html/adm/help/tex/BridgeTask_EditMode.tex	Thu Apr 11 14:59:44 2013
@@ -2,11 +2,11 @@
 
 Another way of creating Bridge Task is via the edit mode. The edit mode allows \
authors to create resources (including Bridge Tasks) online. The basic idea of the \
this editor is the author inserts and deletes different section types into the file \
to build the bridge task.  
-If a task file has already been created, click on the file name followed by the \
"Edit" button to open the file in the colorful editor.  +If a task file has already \
been created, click on the filename followed by the "Edit" button to open the file in \
the colorful editor.   
 If a task file needs to be created:
 \begin{enumerate}
-\item Enter the file name in the area "Create a new directory or LON-CAPA document" \
with the combo box at the left of this set to "New File". The file name must have a \
.task extension. +\item Enter the filename in the area "Create a new directory or \
LON-CAPA document" with the combo box at the left of this set to "New File". The \
filename must have a .task extension.  \item At the second screen, press continue to \
create a new task. At the third screen, select the blank task template and press the \
"Create task" button to create this blank task.   \item To go into the the edit mode, \
press the "Edit" Button.  \end{enumerate}
Index: loncom/html/adm/help/tex/BridgeTask_EditModeFinishing.tex
diff -u loncom/html/adm/help/tex/BridgeTask_EditModeFinishing.tex:1.1 \
                loncom/html/adm/help/tex/BridgeTask_EditModeFinishing.tex:1.2
--- loncom/html/adm/help/tex/BridgeTask_EditModeFinishing.tex:1.1	Wed May 30 15:35:14 \
                2007
+++ loncom/html/adm/help/tex/BridgeTask_EditModeFinishing.tex	Thu Apr 11 14:59:44 \
2013 @@ -1,6 +1,6 @@
 \label{BridgeTask_EditModeFinishing}
 
-Once the construction is complete, click on the "Submit Changes and View" button. \
Click on list to list the current author's directory. The author should now publish \
the file so that the domain coordinator will be able to use the file. To do this \
select publish (or re-publish) in the select action combo box next to the file name. \
+Once the construction is complete, click on the "Submit Changes and View" button. \
Click on list to list the current author's directory. The author should now publish \
the file so that the domain coordinator will be able to use the file. To do this \
select publish (or re-publish) in the select action combo box next to the filename.  
 The LON CAPA interface allows you to view the bridge task from different point of \
views. You can see it from the student's view, the grader view, or the student's view \
after feedback.   \begin{enumerate}
Index: loncom/html/adm/help/tex/BridgeTask_XMLFinishing.tex
diff -u loncom/html/adm/help/tex/BridgeTask_XMLFinishing.tex:1.1 \
                loncom/html/adm/help/tex/BridgeTask_XMLFinishing.tex:1.2
--- loncom/html/adm/help/tex/BridgeTask_XMLFinishing.tex:1.1	Wed May 30 15:35:14 2007
+++ loncom/html/adm/help/tex/BridgeTask_XMLFinishing.tex	Thu Apr 11 14:59:44 2013
@@ -1,6 +1,6 @@
 \label{BridgeTask_XMLFinishing}
 
-Once all questions are written, the file must be closed with the $<$/Task$>$ tag. \
The file must be saved with a .task extension then placed into a LON CAPA author's \
folder. To upload the file simply go to the construction space and simply upload the \
new file using the upload new document button. Once the file is uploaded to LON CAPA, \
the author can publish the file so that the domain coordinator will be able to use \
the file. To do this select publish (or re-publish) in the select action combo box \
next to the file name. +Once all questions are written, the file must be closed with \
the $<$/Task$>$ tag. The file must be saved with a .task extension then placed into a \
LON CAPA author's folder. To upload the file simply go to the construction space and \
simply upload the new file using the upload new document button. Once the file is \
uploaded to LON CAPA, the author can publish the file so that the domain coordinator \
will be able to use the file. To do this select publish (or re-publish) in the select \
action combo box next to the filename.  
 The LON CAPA interface allows you to view the bridge task from different point of \
views. You can see it from the student's view, the grader view, or the student's view \
after feedback:  \begin{enumerate}
Index: loncom/html/adm/help/tex/Portfolio_About.tex
diff -u loncom/html/adm/help/tex/Portfolio_About.tex:1.6 \
                loncom/html/adm/help/tex/Portfolio_About.tex:1.7
--- loncom/html/adm/help/tex/Portfolio_About.tex:1.6	Tue Feb 19 14:45:48 2013
+++ loncom/html/adm/help/tex/Portfolio_About.tex	Thu Apr 11 14:59:44 2013
@@ -8,7 +8,7 @@
 
 Your portfolio works much like file storage on your computer. You may create \
directories and subdirectories to organize your files (See: Creating Directory \
\ref{Portfolio_CreateDirectory}). After creating a directory, you must enter the \
directory (See: Changing Directory \ref{Portfolio_ChangeDirectory}) and upload your \
file (See: Adding Files \ref{Portfolio_AddFiles}) to the current directory.  
-To retrieve a file, find the directory that contains the file then click on the file \
name (See: Opening File \ref{Portfolio_OpenFile}). The file will be downloaded to \
your computer. +To retrieve a file, find the directory that contains the file then \
click on the filename (See: Opening File \ref{Portfolio_OpenFile}). The file will be \
downloaded to your computer.  
 You may share your files by changing the file permissions. You can also find/read \
other people's shared files by going to the other person's personal information page. \
                
Index: loncom/html/adm/help/tex/Portfolio_OpenFile.tex
diff -u loncom/html/adm/help/tex/Portfolio_OpenFile.tex:1.2 \
                loncom/html/adm/help/tex/Portfolio_OpenFile.tex:1.3
--- loncom/html/adm/help/tex/Portfolio_OpenFile.tex:1.2	Tue Nov 28 02:35:53 2006
+++ loncom/html/adm/help/tex/Portfolio_OpenFile.tex	Thu Apr 11 14:59:44 2013
@@ -1,3 +1,3 @@
 \label{Portfolio_OpenFile}
  
-To open a file, click on the file name on the file list. If you cannot see your \
file, you may be in the wrong directory, try changing directories (See Changing \
Directory \ref{Portfolio_ChangeDirectory}). +To open a file, click on the filename on \
the file list. If you cannot see your file, you may be in the wrong directory, try \
                changing directories (See Changing Directory \
                \ref{Portfolio_ChangeDirectory}).
Index: loncom/html/adm/help/tex/Portfolio_RenameFile.tex
diff -u loncom/html/adm/help/tex/Portfolio_RenameFile.tex:1.2 \
                loncom/html/adm/help/tex/Portfolio_RenameFile.tex:1.3
--- loncom/html/adm/help/tex/Portfolio_RenameFile.tex:1.2	Tue Nov 28 02:35:53 2006
+++ loncom/html/adm/help/tex/Portfolio_RenameFile.tex	Thu Apr 11 14:59:44 2013
@@ -1,5 +1,5 @@
  \label{Portfolio_RenameFile}
  
- You can only rename unlocked files. Click on the \underline{rename} link on the \
file you wish to rename. The screen will change to a screen with an input box. Type \
in the new filename in the input box (be sure to write the extension. The extension \
is information used by the operating system on how to open the file). Press \
\textbf{continue} if you wish to rename the file. If you do not want to change the \
file name, press \textbf{Cancel}. + You can only rename unlocked files. Click on the \
\underline{rename} link on the file you wish to rename. The screen will change to a \
screen with an input box. Type in the new filename in the input box (be sure to write \
the extension. The extension is information used by the operating system on how to \
open the file). Press \textbf{continue} if you wish to rename the file. If you do not \
want to change the filename, press \textbf{Cancel}.  
  Invalid characters will be replaced by the character '\_'.
Index: loncom/html/adm/help/tex/Portfolio_ShareFile.tex
diff -u loncom/html/adm/help/tex/Portfolio_ShareFile.tex:1.3 \
                loncom/html/adm/help/tex/Portfolio_ShareFile.tex:1.4
--- loncom/html/adm/help/tex/Portfolio_ShareFile.tex:1.3	Tue Nov 28 02:35:53 2006
+++ loncom/html/adm/help/tex/Portfolio_ShareFile.tex	Thu Apr 11 14:59:44 2013
@@ -8,4 +8,4 @@
 \item Password protected access: To see/download your file, a person must enter the \
password that you have set.  \end{itemize} 
 
-To change the status of a file, click on the \underline{view/change status} link \
after the file name. +To change the status of a file, click on the \
                \underline{view/change status} link after the filename.
Index: loncom/interface/domainprefs.pm
diff -u loncom/interface/domainprefs.pm:1.194 loncom/interface/domainprefs.pm:1.195
--- loncom/interface/domainprefs.pm:1.194	Mon Apr  8 23:01:51 2013
+++ loncom/interface/domainprefs.pm	Thu Apr 11 14:59:48 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to set domain-wide configuration settings
 #
-# $Id: domainprefs.pm,v 1.194 2013/04/08 23:01:51 raeburn Exp $
+# $Id: domainprefs.pm,v 1.195 2013/04/11 14:59:48 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -5454,9 +5454,9 @@
         !defined(&Apache::loncommon::fileembstyle($1))) {
         $output = &mt('Unrecognized file extension ([_1]) - rename the file with a \
proper extension and re-upload.',$1);  } elsif ($file=~/\.(\d+)\.(\w+)$/) {
-        $output = &mt('File name not allowed - rename the file to remove the number \
immediately before the file extension([_1]) and re-upload.',$2); +        $output = \
&mt('Filename not allowed - rename the file to remove the number immediately before \
the file extension([_1]) and re-upload.',$2);  } elsif (-d "$filepath/$file") {
-        $output = &mt('File name is a directory name - rename the file and \
re-upload'); +        $output = &mt('Filename is a directory name - rename the file \
and re-upload');  } else {
         my $source = $filepath.'/'.$file;
         my $logfile;
Index: loncom/interface/loncommon.pm
diff -u loncom/interface/loncommon.pm:1.1119 loncom/interface/loncommon.pm:1.1120
--- loncom/interface/loncommon.pm:1.1119	Tue Apr  2 00:02:02 2013
+++ loncom/interface/loncommon.pm	Thu Apr 11 14:59:48 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common routines
 #
-# $Id: loncommon.pm,v 1.1119 2013/04/02 00:02:02 raeburn Exp $
+# $Id: loncommon.pm,v 1.1120 2013/04/11 14:59:48 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -10123,7 +10123,7 @@
             $output .= &mt('Unrecognized file extension ([_1]) - rename the file \
with a proper extension and re-upload.',$1).'<br />';  next;
         } elsif ($fname=~/\.(\d+)\.(\w+)$/) {
-            $output .= &mt('File name not allowed - rename the file to remove the \
number immediately before the file extension([_1]) and re-upload.',$2).'<br />'; +    \
$output .= &mt('Filename not allowed - rename the file to remove the number \
immediately before the file extension([_1]) and re-upload.',$2).'<br />';  next;
         }
         $env{'form.embedded_item_'.$i.'.filename'}=$fname;
@@ -10825,8 +10825,8 @@
     my ($docudom,$docuname,$file,$destination,$dir_root,$hiddenelem) = @_;
     my ($dir,$error,$warning,$output);
     if ($file !~ /\.(zip|tar|bz2|gz|tar.gz|tar.bz2|tgz)$/) {
-        $error = &mt('File name not a supported archive file type.').
-                 '<br />'.&mt('File name should end with one of: [_1].',
+        $error = &mt('Filename not a supported archive file type.').
+                 '<br />'.&mt('Filename should end with one of: [_1].',
                               '.zip, .tar, .bz2, .gz, .tar.gz, .tar.bz2, .tgz');
     } else {
         my $docuhome = &Apache::lonnet::homeserver($docuname,$docudom);
Index: loncom/localize/localize/de.pm
diff -u loncom/localize/localize/de.pm:1.500 loncom/localize/localize/de.pm:1.501
--- loncom/localize/localize/de.pm:1.500	Tue Apr  9 14:25:24 2013
+++ loncom/localize/localize/de.pm	Thu Apr 11 14:59:53 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # German Localization Lexicon
 #
-# $Id: de.pm,v 1.500 2013/04/09 14:25:24 bisitz Exp $
+# $Id: de.pm,v 1.501 2013/04/11 14:59:53 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -136,7 +136,7 @@
    "You have not selected the format of the student's response data."
 => 'Sie haben kein Format für die Daten der studentischen Antworten ausgewählt.',
 
-   '[_1] will be the uploaded file name [_2]'
+   '[_1] will be the uploaded filename [_2]'
 => '[_1] wird der hochgeladene Dateiname [_2] sein',
 
    '[_1]: point value larger than weight'
@@ -11586,7 +11586,7 @@
    'As this is not the case, most functionality in the system will be unavailable.'
 => 'Da dies momentan nicht der Fall ist, werden die meisten Funktionen des Systems \
nicht zur Verfügung stehen.',  
-   "You have requested to create file in directory [_1] which doesn't exist. The \
requested directory path has been removed from the requested file name." +   "You \
have requested to create file in directory [_1] which doesn't exist. The requested \
directory path has been removed from the requested filename."  => "Schreiben in das \
Verzeichnis [_1] ist nicht möglich, da es nicht existiert. Der entsprechende \
Verzeichnispfad wurde daher entfernt.",  
    'Directory'
@@ -14335,7 +14335,7 @@
    'An error occurred ([_1]) while trying to overwrite [_2].'
 => 'Beim Versuch, [_2] zu überschreiben, ist ein Fehler aufgetreten: [_1]',
 
-   'The new file name was changed from:<br />[_1] to [_2]'
+   'The new filename was changed from:<br />[_1] to [_2]'
 => 'Der neue Dateiname wurde geändert von:<br />[_1] nach [_2]',
 
    'An error occurred ([_1]) while trying to delete access control records for the \
old name.' @@ -19368,7 +19368,7 @@
    'Enrollment Starts'
 => 'Kursbelegung startet',
 
-   'Enter a file name: '
+   'Enter a filename: '
 => 'Geben Sie einen Dateinamen ein: ',
 
    'Font Size'
@@ -22750,7 +22750,7 @@
    'You have already uploaded a file with that filename.'
 => 'Sie hatten bereits eine Datei mit diesem Dateinamen hochgeladen.',
 
-   'Please use a different file name.'
+   'Please use a different filename.'
 => 'Bitte verwenden Sie einen anderen Dateinamen.',
 
    'Size (KB)'
@@ -23320,7 +23320,7 @@
    'Error: update failed for: [_1].'
 => 'Fehler: Aktualisierung für [_1] ist fehlgeschlagen.',
 
-   'File name not allowed - rename the file to remove the number immediately before \
the file extension([_1]) and re-upload.' +   'Filename not allowed - rename the file \
to remove the number immediately before the file extension([_1]) and re-upload.'  => \
'Der Dateiname ist unzulässig. Benennen Sie die Datei so um, dass die Zahl, die \
unmittelbar vor der Dateinamenserweiterung ([_1]) steht, nicht mehr vorhanden ist und \
laden Sie die Datei erneut hoch.',  
    'IDs with the following format(s) may [_1]only[_2] be used for verified users at \
[_3]:' @@ -23680,7 +23680,7 @@
    'The group of bubble lines below responds to a single question.'
 => 'Die Gruppe der Ankreuzfelder-Zeilen bezieht sich auf eine einzelne Frage.',
 
-   'The requested file name was invalid.'
+   'The requested filename was invalid.'
 => 'Der angeforderte Dateiname ist ungültig.',
 
    'There have been multiple bubbles scanned for some question(s)'
@@ -25246,7 +25246,7 @@
    'Failed to write file'
 => 'Das Schreiben der Datei ist fehlgeschlagen.',
 
-   'File name is a directory name - rename the file and re-upload'
+   'Filename is a directory name - rename the file and re-upload'
 => 'Der Dateiname ist der Name eines Verzeichnisses. Benennen Sie die Datei um und \
laden Sie sie erneut hoch.',  
    'File unavailable for display'
@@ -25762,10 +25762,10 @@
    "You will need to modify your upload file so it will include IDs with a different \
format --  ones that will not conflict with 'official' institutional IDs."  => "Sie \
müssen die von Ihnen hochgeladene Datei anpassen, so dass sie IDs in einem anderen \
Format enthält (welche, die nicht in Konflikt mit 'offiziellen' institutionellen IDs \
stehen).",  
-   'File name not a supported archive file type.'
+   'Filename not a supported archive file type.'
 => 'Bei dem Dateinamen handelt es sich um einen nicht unterstützten \
Archivdatei-Typ.',  
-   'File name should end with one of: [_1].'
+   'Filename should end with one of: [_1].'
 => 'Der Dateiname sollte mit einer der folgenden Endungen enden: [_1]',
 
    'File: [_1] added to course'
Index: loncom/localize/localize/pt.pm
diff -u loncom/localize/localize/pt.pm:1.61 loncom/localize/localize/pt.pm:1.62
--- loncom/localize/localize/pt.pm:1.61	Wed Dec 21 13:59:52 2011
+++ loncom/localize/localize/pt.pm	Thu Apr 11 14:59:53 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Portuguese Localization Lexicon
 #
-# $Id: pt.pm,v 1.61 2011/12/21 13:59:52 glusa Exp $
+# $Id: pt.pm,v 1.62 2013/04/11 14:59:53 bisitz Exp $
 #
 # Copyright UNICAMP, Sao Paulo
 # Supported in part by Partnership in Global Learning
@@ -10908,8 +10908,8 @@
    'Enter New Login Data'
 => 'Enter New Login Data',
 
-   'Enter a file name: '
-=> 'Enter a file name: ',
+   'Enter a filename: '
+=> 'Enter a filename: ',
 
    'Enter a maximum of [quant,_1,collaborator] using username or username:domain, \
e.g. smithje or smithje:[_2].'  => 'Enter a maximum of [quant,_1,collaborator] using \
username or username:domain, e.g. smithje or smithje:[_2].', @@ -18248,8 +18248,8 @@
    'The new discussion board was added successfully.<br />'
 => 'The new discussion board was added successfully.<br />',
 
-   'The new file name was changed from:<br />[_1] to [_2]'
-=> 'The new file name was changed from:<br />[_1] to [_2]',
+   'The new filename was changed from:<br />[_1] to [_2]'
+=> 'The new filename was changed from:<br />[_1] to [_2]',
 
    'The new folder may not be named'
 => 'The new folder may not be named',
@@ -20289,8 +20289,8 @@
    'You have requested enabling the previously deleted group [_1].'
 => 'You have requested enabling the previously deleted group [_1].',
 
-   "You have requested to create file in directory [_1] which doesn't exist. The \
                requested directory path has been removed from the requested file \
                name."
-=> "You have requested to create file in directory [_1] which doesn't exist. The \
requested directory path has been removed from the requested file name.", +   "You \
have requested to create file in directory [_1] which doesn't exist. The requested \
directory path has been removed from the requested filename." +=> "You have requested \
to create file in directory [_1] which doesn't exist. The requested directory path \
has been removed from the requested filename.",  
    'You have rights to request the creation of courses and/or communities in the \
following domain(s):'  => 'You have rights to request the creation of courses and/or \
                communities in the following domain(s):',
Index: loncom/localize/localize/zh.pm
diff -u loncom/localize/localize/zh.pm:1.108 loncom/localize/localize/zh.pm:1.109
--- loncom/localize/localize/zh.pm:1.108	Wed Dec 21 13:59:52 2011
+++ loncom/localize/localize/zh.pm	Thu Apr 11 14:59:54 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Chinese Simplified Localization Lexicon
 #
-# $Id: zh.pm,v 1.108 2011/12/21 13:59:52 glusa Exp $
+# $Id: zh.pm,v 1.109 2013/04/11 14:59:54 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -10299,8 +10299,8 @@
    'As this is not the case, most functionality in the system will be unavailable.'
 => 'As this is not the case, most functionality in the system will be unavailable.',
 
-   "You have requested to create file in directory [_1] which doesn't exist. The \
                requested directory path has been removed from the requested file \
                name."
-=> "You have requested to create file in directory [_1] which doesn't exist. The \
requested directory path has been removed from the requested file name.", +   "You \
have requested to create file in directory [_1] which doesn't exist. The requested \
directory path has been removed from the requested filename." +=> "You have requested \
to create file in directory [_1] which doesn't exist. The requested directory path \
has been removed from the requested filename.",  
    'Directory'
 => '目录',
@@ -12794,8 +12794,8 @@
    'An error occurred ([_1]) while trying to rename [_2] to [_3]'
 => 'An error occurred ([_1]) while trying to rename [_2] to [_3]',
 
-   'The new file name was changed from:<br />[_1] to [_2]'
-=> 'The new file name was changed from:<br />[_1] to [_2]',
+   'The new filename was changed from:<br />[_1] to [_2]'
+=> 'The new filename was changed from:<br />[_1] to [_2]',
 
    'An error occurred ([_1]) while trying to delete access control records for the \
old name.'  => 'An error occurred ([_1]) while trying to delete access control \
                records for the old name.',
Index: loncom/publisher/loncfile.pm
diff -u loncom/publisher/loncfile.pm:1.117 loncom/publisher/loncfile.pm:1.118
--- loncom/publisher/loncfile.pm:1.117	Fri Nov 30 11:36:14 2012
+++ loncom/publisher/loncfile.pm	Thu Apr 11 14:59:58 2013
@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.117 2012/11/30 11:36:14 bisitz Exp $
+# $Id: loncfile.pm,v 1.118 2013/04/11 14:59:58 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -235,7 +235,7 @@
 
 =item exists($user, $domain, $file)
 
-   Determine if a resource file name has been published or exists
+   Determine if a resource filename has been published or exists
    in the construction space.
 
  Parameters:
@@ -368,7 +368,7 @@
 	($newpath,$error)=&relativeDest($fn,$newpath,$uname,$udom);
 	if (! -d "$newpath") {
 	    $request->print('<p><span class="LC_warning">'
-                           .&mt("You have requested to create file in directory [_1] \
which doesn't exist. The requested directory path has been removed from the requested \
file name." +                           .&mt("You have requested to create file in \
directory [_1] which doesn't exist. The requested directory path has been removed \
from the requested filename."  ,&display($newpath))
                            .'</span></p>');
 	    $dest=~s|.*/||;
@@ -825,7 +825,7 @@
 
 =item   $domain   - Name of the domain of the user
 
-=item   $fn      - Source file name
+=item   $fn      - Source filename
 
 =item   $newfilename
                   - Name of the file to be created; no path information
@@ -880,7 +880,7 @@
 		'<form name="fileaction" action="/adm/cfile" method="post">'.
                 '<input type="hidden" name="qualifiedfilename" value="'.$fn.'" />'.
 		'<input type="hidden" name="action" value="newfile" />'.
-	        '<span class ="LC_nobreak">'.&mt('Enter a file name: ').'<input type="text" \
name="newfilename" value="Type Name Here" onfocus="if (this.value == '."'Type Name \
Here') this.value=''".'" />&nbsp;<input type="submit" value="Go" />'. +	        \
'<span class ="LC_nobreak">'.&mt('Enter a filename: ').'<input type="text" \
name="newfilename" value="Type Name Here" onfocus="if (this.value == '."'Type Name \
Here') this.value=''".'" />&nbsp;<input type="submit" value="Go" />'.  \
'</span></form></p>'.  '<p><form action="'.&url($fn).
                 '" method="post"><p><input type="submit" value="'.&mt('Cancel').'" \
                /></form></p>');
Index: loncom/publisher/testbankimport.pm
diff -u loncom/publisher/testbankimport.pm:1.37 \
                loncom/publisher/testbankimport.pm:1.38
--- loncom/publisher/testbankimport.pm:1.37	Sun Dec 16 20:06:44 2012
+++ loncom/publisher/testbankimport.pm	Thu Apr 11 14:59:58 2013
@@ -1,5 +1,5 @@
 # Handler for parsing text upload problem descriptions into .problems
-# $Id: testbankimport.pm,v 1.37 2012/12/16 20:06:44 raeburn Exp $
+# $Id: testbankimport.pm,v 1.38 2013/04/11 14:59:58 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -444,7 +444,7 @@
     if ($numitems > 0) {
         my $maxnum = $numitems - 1;
         my %lt = &Apache::lonlocal::texthash(
-                                              fnmb => 'File names must be unique',
+                                              fnmb => 'Filenames must be unique',
                                               isum => 'is used more than once',
                                             );
         $$jsref .= qq|
@@ -681,7 +681,7 @@
     my %lt = &Apache::lonlocal::texthash (
                                           crt  => 'Create?',
                                           typ  => 'Type',
-                                          fnam => 'File Name',
+                                          fnam => 'Filename',
                                           ques => 'Question',
                                           answ => 'Answer',
                                           chka => 'check all',



_______________________________________________
LON-CAPA-cvs mailing list
LON-CAPA-cvs@mail.lon-capa.org
http://mail.lon-capa.org/mailman/listinfo/lon-capa-cvs


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
Index: loncom/interface/portfolio.pm
diff -u loncom/interface/portfolio.pm:1.239 loncom/interface/portfolio.pm:1.240
--- loncom/interface/portfolio.pm:1.239	Mon Dec 17 06:29:02 2012
+++ loncom/interface/portfolio.pm	Thu Apr 11 14:59:49 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # portfolio browser
 #
-# $Id: portfolio.pm,v 1.239 2012/12/17 06:29:02 raeburn Exp $
+# $Id: portfolio.pm,v 1.240 2013/04/11 14:59:49 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -63,7 +63,7 @@
     return $output;
 } 
 
 # receives a file name and path stub from username/userfiles/portfolio/
 # returns an anchor tag consisting encoding filename and currentpath
 sub make_anchor {
     my ($url, $anchor_fields, $inner_text) = @_;
@@ -809,7 +809,7 @@
         return;
     }
     if ($filenewname ne $env{'form.filenewname'}) {
-        $r->print(&mt("The new file name was changed from:<br />[_1] to [_2]",
+        $r->print(&mt("The new filename was changed from:<br />[_1] to [_2]",
 		      '<strong>'.&display_file('',$env{'form.filenewname'}).'</strong>',
 		      '<strong>'.&display_file('',$filenewname).'</strong>'));
     }
@@ -63,7 +63,7 @@
 } 
 
-# receives a file name and path stub from username/userfiles/portfolio/
+# receives a filename and path stub from username/userfiles/portfolio/
 # returns an anchor tag consisting encoding filename and currentpath
 sub make_anchor {